@@ -213,8 +213,7 @@ attribute_buffers <- function(array, sch, dom, sub, selected) {
 
   # first alloc coordinate buffer if we are returning a data.frame
   if(array@as.data.frame) {
-    ncells_coords <- libtiledb_array_max_buffer_elements_with_type(array@ptr, sub,
-                                                                   libtiledb_coords(), domaintype)
+    ncells_coords <- 2*ncells
     if (is.integral(dom)) {
       attributes[["coords"]] <- integer(length = ncells_coords)
     } else {
@@ -234,14 +233,11 @@ attribute_buffers <- function(array, sch, dom, sub, selected) {
     type <- tiledb_datatype_R_type(dtype)
     datatype <- libtiledb_attribute_get_type(attr@ptr)
     #cat("dtype:", dtype, " type:", type, " datatype:", datatype, "\n", sep="")
-    ## If getting it as a dataframe we need to use max buffer elements to get proper buffer size
-    if (array@as.data.frame) {
-      ncells <- libtiledb_array_max_buffer_elements_with_type(array@ptr, sub, aname, domaintype)
-    }
     if (type %in% c("integer", "double")) {
       buff <- vector(mode = type, length = ncells)
     } else if (dtype %in% c("CHAR")) {  # TODO: add other char and date types
-      buff <- libtiledb_query_buffer_var_char_alloc(array@ptr, as.integer(sub), aname)
+      ##buff <- libtiledb_query_buffer_var_char_alloc(array@ptr, as.integer(sub), aname)
+      buff <- libtiledb_query_buffer_var_char_alloc_direct(ncells, ncells*8, FALSE, sub[4]-sub[3]+1)
     } else if (datatype %in% c("DATETIME_DAY", "DATETIME_SEC", "DATETIME_MS",
                                "DATETIME_US", "DATETIME_NS")) {
       buff <- libtiledb_query_buffer_alloc_ptr(array@ptr, datatype, ncells)
